@@ -1,13 +1,12 @@
-use crate::ServiceError;
-use arangors::client::reqwest::ReqwestClient;
-use arangors::Collection;
+use crate::Error;
+use arangors_lite::Collection;
 use std::ops::Deref;
 
-/// Struct containing the connection information on a ArangoDB collection
+/// Struct containing the connection information on a `ArangoDB` collection
 #[derive(Debug, Clone)]
 pub struct DatabaseCollection {
-    /// The collection wrapper accessor of `arangors` crate driver
-    collection: Collection<ReqwestClient>,
+    /// The collection wrapper accessor of `arangors_lite` crate driver
+    collection: Collection,
 }
 
 impl DatabaseCollection {
@@ -21,12 +20,12 @@ impl DatabaseCollection {
     /// # Returns
     ///
     /// On success a `i32` is returned as the document count.
-    /// On failure a ServiceError wil be returned.
+    /// On failure a Error wil be returned.
     #[maybe_async::maybe_async]
-    pub async fn record_count(&self) -> Result<u32, ServiceError> {
+    pub async fn record_count(&self) -> Result<u32, Error> {
         let properties = match self.collection.document_count().await {
             Ok(value) => value,
-            Err(client_error) => return Err(ServiceError::from(client_error)),
+            Err(client_error) => return Err(Error::from(client_error)),
         };
         match properties.info.count {
             Some(value) => Ok(value),
@@ -35,14 +34,14 @@ impl DatabaseCollection {
     }
 }
 
-impl From<Collection<ReqwestClient>> for DatabaseCollection {
-    fn from(collection: Collection<ReqwestClient>) -> Self {
+impl From<Collection> for DatabaseCollection {
+    fn from(collection: Collection) -> Self {
         Self { collection }
     }
 }
 
 impl Deref for DatabaseCollection {
-    type Target = Collection<ReqwestClient>;
+    type Target = Collection;
 
     fn deref(&self) -> &Self::Target {
         &self.collection
