@@ -1,4 +1,4 @@
-use crate::{DatabaseAccess, DatabaseRecord, Record, ServiceError, Validate};
+use crate::{DatabaseAccess, DatabaseRecord, Error, Record, Validate};
 use serde::{Deserialize, Serialize};
 use std::ops::{Deref, DerefMut};
 
@@ -13,10 +13,10 @@ use std::ops::{Deref, DerefMut};
 /// [`Record`]: trait.Record.html
 #[derive(Serialize, Deserialize, Clone)]
 pub struct EdgeRecord<T> {
-    /// The `_from` field of ArangoDB edge documents
+    /// The `_from` field of `ArangoDB` edge documents
     #[serde(rename(serialize = "_from", deserialize = "_from"))]
     from: String,
-    /// The `to` field of ArangoDB edge documents
+    /// The `to` field of `ArangoDB` edge documents
     #[serde(rename(serialize = "_to", deserialize = "_to"))]
     to: String,
     /// The main document data, must implement [`Record`].
@@ -37,10 +37,10 @@ impl<T: Record> EdgeRecord<T> {
     /// * `id_to` - The **to** document `id`
     /// * `data` - The main document data
     ///
-    /// # Failure
+    /// # Errors
     ///
     /// This function validates the format of the id fields which can result in an error.
-    pub fn new(id_from: String, id_to: String, data: T) -> Result<Self, ServiceError> {
+    pub fn new(id_from: String, id_to: String, data: T) -> Result<Self, Error> {
         let res = Self {
             from: id_from,
             to: id_to,
@@ -52,7 +52,7 @@ impl<T: Record> EdgeRecord<T> {
 
     /// Retrieves the `from` document from the database
     #[maybe_async::maybe_async]
-    pub async fn from_record<D, R>(&self, db_access: &D) -> Result<DatabaseRecord<R>, ServiceError>
+    pub async fn from_record<D, R>(&self, db_access: &D) -> Result<DatabaseRecord<R>, Error>
     where
         D: DatabaseAccess + ?Sized,
         R: Record,
@@ -62,7 +62,7 @@ impl<T: Record> EdgeRecord<T> {
 
     /// Retrieves the `to` document from the database
     #[maybe_async::maybe_async]
-    pub async fn to_record<D, R>(&self, db_access: &D) -> Result<DatabaseRecord<R>, ServiceError>
+    pub async fn to_record<D, R>(&self, db_access: &D) -> Result<DatabaseRecord<R>, Error>
     where
         D: DatabaseAccess + ?Sized,
         R: Record,
@@ -82,7 +82,7 @@ impl<T: Record> EdgeRecord<T> {
 
     /// Parses the `from` value to retrieve only the `_key` part.
     ///
-    /// # Panic
+    /// # Panics
     ///
     /// This method may panic if the `from` value is not formatted correctly.
     pub fn key_from(&self) -> String {
@@ -91,7 +91,7 @@ impl<T: Record> EdgeRecord<T> {
 
     /// Parses the `to` value to retrieve only the `_key` part.
     ///
-    /// # Panic
+    /// # Panics
     ///
     /// This method may panic if the `to` value is not formatted correctly.
     pub fn key_to(&self) -> String {
@@ -100,7 +100,7 @@ impl<T: Record> EdgeRecord<T> {
 
     /// Parses the `from` value to retrieve only the collection name part.
     ///
-    /// # Panic
+    /// # Panics
     ///
     /// This method may panic if the `to` value is not formatted correctly.
     pub fn to_collection_name(&self) -> String {
@@ -109,7 +109,7 @@ impl<T: Record> EdgeRecord<T> {
 
     /// Parses the `to` value to retrieve only the collection name part.
     ///
-    /// # Panic
+    /// # Panics
     ///
     /// This method may panic if the `from` value is not formatted correctly.
     pub fn from_collection_name(&self) -> String {
@@ -118,7 +118,7 @@ impl<T: Record> EdgeRecord<T> {
 
     fn validate_edge_fields(&self, errors: &mut Vec<String>) {
         let array = [("from", self.id_from()), ("to", self.id_to())];
-        for (name, field) in array.iter() {
+        for (name, field) in array {
             let split = field.split('/').collect::<Vec<&str>>();
             if split.len() != 2 {
                 errors.push(format!(r#"{} "{}" has wrong format"#, name, field));
@@ -142,7 +142,7 @@ impl<T: Record> Validate for EdgeRecord<T> {
 impl<T: Record + Send> Record for EdgeRecord<T> {
     const COLLECTION_NAME: &'static str = T::COLLECTION_NAME;
 
-    async fn before_create_hook<D>(&mut self, db_accessor: &D) -> Result<(), ServiceError>
+    async fn before_create_hook<D>(&mut self, db_accessor: &D) -> Result<(), Error>
     where
         D: DatabaseAccess + ?Sized,
     {
@@ -150,28 +150,28 @@ impl<T: Record + Send> Record for EdgeRecord<T> {
         self.data.before_create_hook(db_accessor).await
     }
 
-    async fn before_save_hook<D>(&mut self, db_accessor: &D) -> Result<(), ServiceError>
+    async fn before_save_hook<D>(&mut self, db_accessor: &D) -> Result<(), Error>
     where
         D: DatabaseAccess + ?Sized,
     {
         self.data.before_save_hook(db_accessor).await
     }
 
-    async fn before_delete_hook<D>(&mut self, db_accessor: &D) -> Result<(), ServiceError>
+    async fn before_delete_hook<D>(&mut self, db_accessor: &D) -> Result<(), Error>
     where
         D: DatabaseAccess + ?Sized,
     {
         self.data.before_delete_hook(db_accessor).await
     }
 
-    async fn after_create_hook<D>(&mut self, db_accessor: &D) -> Result<(), ServiceError>
+    async fn after_create_hook<D>(&mut self, db_accessor: &D) -> Result<(), Error>
     where
         D: DatabaseAccess + ?Sized,
     {
         self.data.after_create_hook(db_accessor).await
     }
 
-    async fn after_save_hook<D>(&mut self, db_accessor: &D) -> Result<(), ServiceError>
+    async fn after_save_hook<D>(&mut self, db_accessor: &D) -> Result<(), Error>
     where
         D: DatabaseAccess + ?Sized,
     {
@@ -179,7 +179,7 @@ impl<T: Record + Send> Record for EdgeRecord<T> {
         self.data.after_save_hook(db_accessor).await
     }
 
-    async fn after_delete_hook<D>(&mut self, db_accessor: &D) -> Result<(), ServiceError>
+    async fn after_delete_hook<D>(&mut self, db_accessor: &D) -> Result<(), Error>
     where
         D: DatabaseAccess + ?Sized,
     {
