@@ -1,31 +1,39 @@
+//! [![Logo](https://gitlab.com/qonfucius/aragog/-/snippets/2090578/raw/master/logo.svg)](http://aragog.rs)
+//!
 //! # Aragog
 //!
 //! [![pipeline status](https://gitlab.com/qonfucius/aragog/badges/master/pipeline.svg)](https://gitlab.com/qonfucius/aragog/commits/master)
 //! [![MIT licensed](https://img.shields.io/badge/license-MIT-blue.svg)](./LICENSE)
 //! [![Crates.io](https://img.shields.io/crates/v/aragog.svg)](https://crates.io/crates/aragog)
 //! [![aragog](https://docs.rs/aragog/badge.svg)](https://docs.rs/aragog)
+//! [![dependency status](https://deps.rs/crate/aragog/0.16.0/status.svg)](https://deps.rs/crate/aragog)
+//!
 //! [![Discord](https://img.shields.io/discord/763034131335741440.svg?label=&logo=discord&logoColor=ffffff&color=7389D8&labelColor=6A7EC2)](https://discord.gg/Xyx3hUP)
 //! [![Gitter](https://badges.gitter.im/aragog-rs/community.svg)](https://gitter.im/aragog-rs/community)
 //!
-//! `aragog` is a fully featured ODM and OGM library for [ArangoDB][ArangoDB] using the [arangors][arangors] driver.
+//! `aragog` is a fully featured ODM and OGM library for [`ArangoDB`][ArangoDB] using the [`arangors_lite`][arangors_lite] driver.
 //!
-//! The main concept is to provide behaviors allowing to map your structs with ArangoDB documents as simply an lightly as possible.
+//! The main concept is to provide behaviors allowing to map your structs with `ArangoDB` documents as simply an lightly as possible.
 //! Inspired by Rails's [Active Record](https://github.com/rails/rails/tree/main/activerecord) library
-//! `aragog` aslo provides **hooks** and **validations** for your models.
+//! `aragog` also provides **hooks** and **validations** for your models.
 //!
-//! The crate also provides a powerful [AQL][AQL] querying tool allowing complex and safe ArangoDB queries in *Rust*.
+//! The crate also provides a powerful [AQL][AQL] querying tool allowing complex and safe `ArangoDB` queries in *Rust*.
+//!
+//! See the [official website](http://aragog.rs)
+//!
+//! Minimum rust version: `1.46` (2018 edition)
 //!
 //! ## Migrations CLI
 //!
-//! `aragog` provides a safe schema generation and migrations command line interface: [aragog_cli][CLI].
+//! `aragog` provides a safe schema generation and migrations command line interface: [`aragog_cli`][CLI].
 //!
 //! ## Features
 //!
 //! By now the available features are:
-//! * Creating a database connection from a defined `schema.yaml` (See [aragog_cli][CLI])
+//! * Creating a database connection from a defined `schema.yaml` (See [`aragog_cli`][CLI])
 //! * Structures can implement different behaviors:
-//!     * `Record`: The structure can be written and retrieved as an ArangoDB [collection document][collection_document]. This is the main trait for your models
-//!     * `EdgeRecord`: The structure can be written and retrieved as an ArangoDB [edge collection document][edge_document]
+//!     * `Record`: The structure can be written and retrieved as an `ArangoDB` [collection document][collection_document]. This is the main trait for your models
+//!     * `EdgeRecord`: The structure can be written and retrieved as an `ArangoDB` [edge collection document][edge_document]
 //!     * `Validate`: The structure can perform simple validations before being created or saved into the database.
 //!     * `Link`: The structure can define relations with other models based on defined queries.
 //!     * `ForeignLink`: The structure can define relations with other models based on defined foreign key.
@@ -33,7 +41,7 @@
 //!     * `AuthorizeAction`: The structure can define authorization behavior on a target record with custom Action type.
 //!     * `New`: The structure can be initialized from an other type (a form for example). It allows to maintain a privacy level in the model and to use different data formats.
 //!     * `Update`: The structure can be updated from an other type (a form for example). It allows to maintain a privacy level in the model and to use different data formats.
-//! * Different operations can return a `ServiceError` error that can easily be transformed into a Http Error
+//! * Different operations can return a `Error` error that can easily be transformed into a Http Error
 //! * Transactional operations
 //!
 //! For detailed explanations on theses feature, read the [book](https://gitlab.com/qonfucius/aragog/-/tree/master/book) ([published version](https://aragog.rs/book))
@@ -42,7 +50,7 @@
 //!
 //! ### Schema and collections
 //!
-//! In order for everything to work you need a `schema.yaml` file. Use [aragog_cli][CLI] to create migrations and generate the file.
+//! In order for everything to work you need a `schema.yaml` file. Use [`aragog_cli`][CLI] to create migrations and generate the file.
 //!
 //! ### Creating a database connection
 //!
@@ -90,7 +98,7 @@
 //! The global architecture is simple, every *model* you define that can be synced with the database must implement `serde::Serialize`, `serde::Deserialize` and `Clone`.
 //! To declare a `struct` as a Model it must derive from `aragog::Record` (the collection name must be the same as the struct) or implement it.
 //!
-//! The final *model* structure will be an **Exact** representation of the content of a ArangoDB *document*, so without its `_key`, `_id` and `_rev`.
+//! The final *model* structure will be an **Exact** representation of the content of a `ArangoDB` *document*, so without its `_key`, `_id` and `_rev`.
 //! Your project should contain some `models` folder with every `struct` representation of your database documents.
 //!
 //! The real representation of a complete document is `DatabaseRecord<T>` where `T` is your model structure.
@@ -236,7 +244,7 @@
 //!
 //! ### Querying
 //!
-//! You can retrieve a document from the database as simply as it gets, from the unique ArangoDB `_key` or from multiple conditions.
+//! You can retrieve a document from the database as simply as it gets, from the unique `ArangoDB` `_key` or from multiple conditions.
 //! The example below show different ways to retrieve records, look at each function documentation for more exhaustive exaplanations.
 //!
 //! **Example**
@@ -362,7 +370,7 @@
 //! // Macro
 //! compare!(field "some_field").some_comparison("compared_value");
 //!
-//! // for field arrays (see ArangoDB operators)
+//! // for field arrays (see `ArangoDB` operators)
 //!
 //! // Explicit
 //! Comparison::all("some_field_array").some_comparison("compared_value");
@@ -379,7 +387,7 @@
 //! // Macro
 //! compare!(none "some_field_array").some_comparison("compared_value");
 //! ```
-//! All the currently implemented comparison methods are listed under [ComparisonBuilder][ComparisonBuilder] documentation page.
+//! All the currently implemented comparison methods are listed under [`ComparisonBuilder`][ComparisonBuilder] documentation page.
 //!
 //! Filters can be defined explicitely like this:
 //!
@@ -460,10 +468,10 @@
 //!     );
 //! ```
 //!
-//! [arangors]: https://docs.rs/arangors
+//! [arangors_lite]: https://docs.rs/arangors_lite
 //! [argonautica]: https://github.com/bcmyers/argonautica
 //! [ArangoDB]: https://www.arangodb.com/
-//! [IndexSettings]: https://docs.rs/arangors/latest/arangors/index/enum.IndexSettings.html
+//! [IndexSettings]: https://docs.rs/arangors_lite/latest/arangors_lite/index/enum.IndexSettings.html
 //! [ComparisonBuilder]: https://docs.rs/aragog/latest/aragog/query/struct.ComparisonBuilder.html
 //! [CLI]: https://crates.io/crates/aragog_cli
 //! [edge_document]: https://www.arangodb.com/docs/stable/data-modeling-documents-document-methods.html#edges
@@ -472,24 +480,22 @@
 //! [arango_doc]: https://www.arangodb.com/docs/stable/getting-started.html "Arango getting started"
 //! [AQL]: https://www.arangodb.com/docs/stable/aql/ "AQL"
 //!
-#![forbid(missing_docs)]
+#![doc(html_logo_url = "https://gitlab.com/qonfucius/aragog/-/snippets/2215922/raw/main/logo.svg")]
 #![forbid(unsafe_code)]
-#![deny(warnings)]
-#![warn(rustdoc::broken_intra_doc_links)]
+#![warn(
+    clippy::all,
+    clippy::correctness,
+    clippy::suspicious,
+    clippy::style,
+    clippy::complexity,
+    clippy::perf,
+    nonstandard_style,
+    missing_docs,
+    rustdoc::broken_intra_doc_links
+)]
 
 pub extern crate async_trait;
 
-#[cfg(all(feature = "async", feature = "blocking"))]
-compile_error!(
-    r#"feature "blocking" and "async" cannot be set at the same time.
-    If what you want is "blocking", please turn off default features by adding "default-features=false" in your Cargo.toml"#
-);
-
-#[cfg(all(not(feature = "async"), not(feature = "blocking")))]
-compile_error!(
-    r#"feature "blocking" and "async" cannot be disabled at the same time. Enable one of them"#
-);
-
 #[cfg(feature = "derive")]
 #[doc(hidden)]
 pub use aragog_macros::*;
@@ -500,7 +506,7 @@ pub use {
     db::database_access::DatabaseAccess, db::database_connection::AuthMode,
     db::database_connection::DatabaseConnection, db::database_record::DatabaseRecord,
     db::operation_options::OperationOptions, db::transaction, edge_record::EdgeRecord,
-    error::ServiceError, foreign_link::ForeignLink, link::Link, record::Record,
+    error::Error, foreign_link::ForeignLink, link::Link, record::Record,
     undefined_record::UndefinedRecord, validate::Validate,
 };
 
