@@ -1,10 +1,9 @@
 use crate::schema::SchemaDatabaseOperation;
-use arangors::client::reqwest::ReqwestClient;
-use arangors::graph::Graph;
-use arangors::{ClientError, Database};
+use arangors_lite::graph::Graph;
+use arangors_lite::{ClientError, Database};
 use serde::{Deserialize, Serialize};
 
-/// Aragog schema representation of an ArangoDB Named Graph.
+/// Aragog schema representation of an `ArangoDB` Named Graph.
 /// This struct is meant to load/generate the schema file.
 #[derive(Debug, Serialize, Deserialize, Clone)]
 pub struct GraphSchema(pub Graph);
@@ -21,7 +20,7 @@ impl SchemaDatabaseOperation for GraphSchema {
 
     async fn apply_to_database(
         &self,
-        database: &Database<ReqwestClient>,
+        database: &Database,
         silent: bool,
     ) -> Result<Option<Self::PoolType>, ClientError> {
         log::debug!("Creating Graph {}", &self.0.name);
@@ -29,13 +28,13 @@ impl SchemaDatabaseOperation for GraphSchema {
         Self::handle_pool_result(database.create_graph(graph, true).await, silent)
     }
 
-    async fn drop(&self, database: &Database<ReqwestClient>) -> Result<(), ClientError> {
+    async fn drop(&self, database: &Database) -> Result<(), ClientError> {
         log::debug!("Deleting Graph {}", &self.0.name);
         database.drop_graph(&self.0.name, false).await?;
         Ok(())
     }
 
-    async fn get(&self, database: &Database<ReqwestClient>) -> Result<Self::PoolType, ClientError> {
+    async fn get(&self, database: &Database) -> Result<Self::PoolType, ClientError> {
         database.graph(&self.0.name).await
     }
 }
