@@ -1,6 +1,6 @@
 use regex::Regex;
 
-use crate::ServiceError;
+use crate::Error;
 use std::fmt::Display;
 use std::slice;
 
@@ -39,14 +39,18 @@ use std::slice;
 /// ```
 /// [`Record`]: trait.Record.html
 pub trait Validate {
-    /// Validates the object field formats, logic or anything. Calls the [`validations`] method
-    /// and will render a complete [`ServiceError`]::[`ValidationError`] on validation failure.
-    /// On success returns `()`
+    /// Validates the object field formats, logic or anything.
+    ///
+    /// Calls the [`validations`] method and return `()` on success.
+    ///
+    /// # Errors
+    ///
+    /// Will render a complete [`Error`]::[`ValidationError`] on validation failure.
     ///
     /// [`validations`]: trait.Validate.html#tymethod.validations
-    /// [`ServiceError`]: enum.ServiceError.html
-    /// [`ValidationError`]: enum.ServiceError.html#variant.ValidationError
-    fn validate(&self) -> Result<(), ServiceError> {
+    /// [`Error`]: enum.Error.html
+    /// [`ValidationError`]: enum.Error.html#variant.ValidationError
+    fn validate(&self) -> Result<(), Error> {
         let mut errors: Vec<String> = Vec::new();
 
         self.validations(&mut errors);
@@ -56,7 +60,7 @@ pub trait Validate {
         } else {
             let error_str = errors.join(", ");
             log::error!("{}", &error_str);
-            Err(ServiceError::ValidationError(error_str))
+            Err(Error::ValidationError(error_str))
         }
     }
 
@@ -578,7 +582,7 @@ mod tests {
                     &mut errors
                 ));
                 assert!(errors.is_empty());
-                for wrong_str in wrong_strs.iter() {
+                for wrong_str in &wrong_strs {
                     assert!(!TestElem::validate_numeric_string(
                         STRING_EMPTY,
                         wrong_str,
@@ -606,7 +610,7 @@ mod tests {
                     "010203040005",
                 ];
 
-                for correct_str in correct_strs.iter() {
+                for correct_str in &correct_strs {
                     assert!(TestElem::validate_max_len(
                         STRING_EMPTY,
                         &String::from(correct_str.deref()),
